@@ -3,7 +3,11 @@ __copyright__ = "Copyright (c) 2021-2021 SZI"
 # Use of this source code is governed by the MIT license.
 __license__ = "MIT"
 
+# -*- coding: utf-8 -*-
+
 import json
+from turtle import st
+from numpy import number
 import requests
 from bs4 import BeautifulSoup
 
@@ -24,7 +28,7 @@ class ArcaAPI():
         self.logined = False
         self.kwarg = kwargs
 
-    def Csrf_get(self, URL):
+    def Csrf_get(self, URL: str):
         html = self.curSession.get(URL, **self.kwarg)
         soup = BeautifulSoup(html.text, 'html.parser')
         csrf = ''
@@ -67,21 +71,21 @@ class ArcaAPI():
         if a.status_code > 202:
             raise ArcaError('HTML ERROR ' + str(a.status_code))
 
-    def login(self, id, password):
+    def login(self, id: str, password: str):
         URL = 'https://arca.live/u/login'
         payload = {'username': id, 'password': password, 'goto': '/', '_csrf': self.Csrf_get(URL)[0]}
         a = self.curSession.post(URL, data=payload)
         self.check_for_error(a)
         self.logined = True
 
-    def delete_post(self, id):
+    def delete_post(self, id: number):
         id = str(id)
         URL = 'https://arca.live/b/chan/' + id + '/delete'
         payload = {'_csrf': self.Csrf_get(URL)[0]}
         a = self.curSession.post(URL, data=payload)
         self.check_for_error(a)
 
-    def delete_comment(self, pid, id):
+    def delete_comment(self, pid: number, id: number):
         id = str(id)
         pid = str(pid)
         URL = 'https://arca.live/b/chan/' + pid + '/' + id + '/delete'
@@ -89,7 +93,7 @@ class ArcaAPI():
         a = self.curSession.post(URL, data=payload)
         self.check_for_error(a)
 
-    def post_article(self, channel, name, content, category=None, copy_humor=False, agree_prevent_delete=False):
+    def post_article(self, channel: str, name:str, content:str, category:str=None, copy_humor:bool=False, agree_prevent_delete:bool=False):
         URL = 'https://arca.live/b/' + channel + '/write'
         csrf = self.Csrf_get(URL)
         payload = {'_csrf': csrf[0],
@@ -106,13 +110,13 @@ class ArcaAPI():
         a = self.curSession.post(URL, data=payload)
         self.check_for_error(a)
 
-    def get_channel_info(self, channel):
+    def get_channel_info(self, channel: str):
         response = {}
         URL = 'https://arca.live/b/' + channel
         html = self.curSession.get(URL, **self.kwarg)
         self.check_for_error(html)
         soup = BeautifulSoup(html.text, 'html.parser')
-        sh = soup.find_all('div', 'board-title')  # 채널 이름 구하기
+        sh = soup.find_all('div', 'board-title')
         response['name'] = ''
         for y in sh:
             try:
@@ -131,7 +135,7 @@ class ArcaAPI():
         except:
             response['juddak'] = ''
 
-        sh = soup.find_all('ul', 'board-category')[0].find_all('a')  # 글머리 구하기
+        sh = soup.find_all('ul', 'board-category')[0].find_all('a')
         response['category'] = []
         for x in range(len(sh)):
             y = ({'display_name': sh[x].text, 'name': sh[x].attrs['href'].replace('/b/' + channel, '')})
@@ -140,8 +144,8 @@ class ArcaAPI():
                 response['category'].append(y)
         return response
 
-    def get_channel_article(self, channel, page=1, best=False, category=None, cut_rate=None, sort=None, search=None,
-                            search_target=None):
+    def get_channel_article(self, channel:str, page:number=1, best:bool=False, category:bool=None, cut_rate:bool=None, sort:bool=None, search:bool=None,
+                            search_target:bool=None):
         URL = 'https://arca.live/b/' + channel + '?p=' + str(page)
         if best:
             URL += '&mode=best'
@@ -216,7 +220,7 @@ class ArcaAPI():
                 pass
         return response
 
-    def get_article(self, id):
+    def get_article(self, id:number):
         response = {}
         URL = 'https://arca.live/b/a/' + str(id)
         html = self.curSession.get(URL, **self.kwarg)
@@ -258,12 +262,13 @@ class ArcaAPI():
                     comment['user'] = x.find('span', 'user-info').find('span').attrs['data-filter']
                 except:
                     pass
-            comment['comment_id'] = (int(x.attrs['id'].replace('c_', '')))
+            id_attrs = x.find('div', {'class': 'comment-item'}).attrs['id']
+            comment['comment_id'] = (int(id_attrs.replace('c_', '')))
             response['comment'].append(comment)
         response['content'] = (soup.find('div', 'fr-view article-content'))
         return response
 
-    def post_comment(self, id, message, reply_to=None):
+    def post_comment(self, id:number, message:str, reply_to=None):
         URL = 'https://arca.live/b/maplete/' + str(id)
         html = self.curSession.get(URL, **self.kwarg)
         self.check_for_error(html)
@@ -276,7 +281,7 @@ class ArcaAPI():
         a = self.curSession.post(URL + '/comment', data=payload)
         self.check_for_error(a)
 
-    def like(self, id, dislike=False):
+    def like(self, id:number, dislike=False):
         URL = 'https://arca.live/b/maplete/' + str(id)
         html = self.curSession.get(URL, **self.kwarg)
         idurl = html.url.split('/')
